<?php

namespace Vmc\Blog\Providers;

use Litepie\Contracts\Workflow\Workflow as WorkflowContract;
use Litepie\Foundation\Support\Providers\WorkflowServiceProvider as ServiceProvider;

class WorkflowServiceProvider extends ServiceProvider
{
    /**
     * The validators mappings for the package.
     *
     * @var array
     */
    protected $validators = [
        // Bind Category validator
        \Vmc\Blog\Models\Category::class => \Vmc\Blog\Workflow\CategoryValidator::class,

        // Bind Blog validator
        \Vmc\Blog\Models\Blog::class => \Vmc\Blog\Workflow\BlogValidator::class,
    ];

    /**
     * The actions mappings for the package.
     *
     * @var array
     */
    protected $actions = [
        // Bind Category actions
        \Vmc\Blog\Models\Category::class => \Vmc\Blog\Workflow\CategoryAction::class,

        // Bind Blog actions
        \Vmc\Blog\Models\Blog::class => \Vmc\Blog\Workflow\BlogAction::class,
    ];

    /**
     * The notifiers mappings for the package.
     *
     * @var array
     */
    protected $notifiers = [
       // Bind Category notifiers
        \Vmc\Blog\Models\Category::class => \Vmc\Blog\Workflow\CategoryNotifier::class,

        // Bind Blog notifiers
        \Vmc\Blog\Models\Blog::class => \Vmc\Blog\Workflow\BlogNotifier::class,
    ];

    /**
     * Register any package workflow validation services.
     *
     * @param \Litepie\Contracts\Workflow\Workflow $workflow
     *
     * @return void
     */
    public function boot(WorkflowContract $workflow)
    {
        parent::registerValidators($workflow);
        parent::registerActions($workflow);
        parent::registerNotifiers($workflow);
    }
}
